@@ -9,8 +9,8 @@ fn main() {
     let _ = VirtualDom::new(parent);
 }
 
-fn parent(cx: Scope<()>) -> Element {
-    let value = cx.use_hook(|_| String::new(), |f| f);
+fn parent(cx: Scope) -> Element {
+    let value = cx.use_hook(|_| String::new());
 
     cx.render(rsx! {
         div {
